@@ -60,6 +60,7 @@ public:
 
 class Interpreter;
 class UserClass;
+class JIT;
 
 typedef Array (*BinaryFunc)(Array, Array, Interpreter*);
 typedef Array (*UnaryFunc)(Array, Interpreter*);
@@ -118,10 +119,18 @@ class Interpreter : public QThread {
    * autostop storage flag
    */
   bool autostop;
+  /**
+   * in try block flag
+   */
+  bool intryblock;
   /**
    * jit control flag
    */
   bool jitcontrol;
+  /**
+   * jit instance for this interpreter
+   */
+  JIT *m_jit;
   /**
    * When this flag is active, autostop does nothing.
    */
@@ -133,11 +142,11 @@ class Interpreter : public QThread {
   /**
    * The command buffer
    */
-  vector<string> cmd_buffer;
+  StringVector cmd_buffer;
   /**
    * A buffer of return values from graphics calls
    */
-  vector<ArrayVector> gfx_buffer;
+  QVector<ArrayVector> gfx_buffer;
   /**
    * A flag to indicate that the gfx call failed
    */
@@ -165,11 +174,11 @@ class Interpreter : public QThread {
    * For technical reasons, the interpreter stores a mirror of the call stack
    * in this member.
    */
-  vector<stackentry> cstack;
+  QVector<stackentry> cstack;
   /**
    * A list of breakpoints
    */
-  vector<stackentry> bpStack;
+  QVector<stackentry> bpStack;
   /**
    * True if the interpreter is in single-step mode
    */
@@ -251,6 +260,10 @@ class Interpreter : public QThread {
    * The capture state
    */
   bool m_captureState;
+  /**
+   * The profile state
+   */
+  bool m_profile;
   /**
    * The quiet level
    */
@@ -305,6 +318,11 @@ public:
   inline void clearCaptureString() {m_capture = "";}
   inline void setCaptureState(bool t) {m_captureState = t;}
   inline string getCaptureString() {return m_capture;}
+  /**
+   * Manipulate the profile state
+   */
+  inline void setProfileState(bool t) {m_profile = t;}
+  inline bool profileState() {return m_profile;}
   /**
    * Get the result of the thread function evaluation
    */
@@ -335,6 +353,15 @@ public:
    */
   string getMFileName();
   string getInstructionPointerFileName();
+  inline string sampleInstructionPointer(unsigned &context) const {
+    if (!InCLI) {
+      context = ip_context & 0x0000FFFF; 
+      return ip_funcname;
+    } else {
+      context = 0;
+      return "CLI";
+    }
+  }
   /**
    * The Base Path is the one that contains .m files in the current app bundle
    */
@@ -355,11 +382,6 @@ public:
    * Set the path for the interface. (user path - legacy interface)
    */
   void setPath(string);
-  /**
-   * Force a rescan of the current path to look for 
-   * new function files.
-   */
-  void rescanPath();
   /**
    * Return the width of the current "terminal" in
    * characters.
@@ -466,19 +488,23 @@ public:
   /**
    * Step the given number of lines
    */
-  void dbstepStatement(const tree &t);
-  void dbtraceStatement(const tree &t);
+  void dbstepStatement(Tree* t);
+  void dbtraceStatement(Tree* t);
   /**
    * Set the autostop flag - this flag determines what happens when
    * an exception occurs
    */
   inline bool AutoStop() {return autostop;}
-  inline void AutoStop(bool a) {autostop = a;}
+  inline void setAutoStop(bool a) {autostop = a;}
   /**
    * Set the JITControl flag
    */
   inline bool JITControl() {return jitcontrol;}
-  inline void JITControl(bool a) {jitcontrol = a;}
+  inline void setJITControl(bool a) {jitcontrol = a;}
+  /**
+   * Get the JIT pointer
+   */
+  JIT* JITPointer();
   /**
    * Set the print limit (number of element printed prior to truncation).
    */
@@ -535,7 +561,7 @@ public:
    * lasterr string is also set to the contents of the exception.
    *
    */
-  void block(const tree &t);
+  void block(Tree *t);
   /**
    * Start a command line interface.  Statements are retrieved
    * from the console, and executed sequentially until a "return"
@@ -546,7 +572,11 @@ public:
   bool isBPSet(QString fname, int lineNumber);
   bool isInstructionPointer(QString fname, int lineNumber);
   void toggleBP(QString fname, int lineNumber);
-
+  /**
+   * Force a rescan of the current path to look for 
+   * new function files.
+   */
+  void rescanPath();
   /******************************************
    *  Signals for the Interpreter           *
    ******************************************/
@@ -586,6 +616,10 @@ signals:
   /**
    * Show the current active line
    */
+  void IllegalLineOrCurrentPath(string name, int line);
+  /**
+   * Inform the editor of illegal line or file not on current path
+   */
   void ShowActiveLine();
   /**
    * Enable repainting
@@ -611,19 +645,19 @@ private:
    * Collect information about keyword usage and the relevant 
    * expressions from a function call
    */
-  void collectKeywords(const tree &q, ArrayVector &keyvals,
-		       treeVector &keyexpr, stringVector &keywords);
+  void collectKeywords(Tree *q, ArrayVector &keyvals,
+		       TreeList &keyexpr, StringVector &keywords);
   /**
    * Sort keywords into a proper call order.
    */
-  int* sortKeywords(ArrayVector &m, stringVector &keywords,
-		    stringVector arguments, ArrayVector keyvals);
+  int* sortKeywords(ArrayVector &m, StringVector &keywords,
+		    StringVector arguments, ArrayVector keyvals);
   /**
    * For values passed by reference, update the caller's variables.
    */
-  void handlePassByReference(const tree &q, stringVector arguments,
-			     ArrayVector m,stringVector keywords,
-			     treeVector keyexpr, int* argTypeMap);
+  void handlePassByReference(Tree *q, StringVector arguments,
+			     ArrayVector m,StringVector keywords,
+			     TreeList keyexpr, int* argTypeMap);
   /**
    * Create a variable in the correct scope, and return a reference to it
    */
@@ -631,19 +665,19 @@ private:
   /**
    * Perform a binary operator with the given name
    */
-  Array DoBinaryOperator(const tree &t, BinaryFunc fnc, string fname);
+  Array DoBinaryOperator(Tree *t, BinaryFunc fnc, string fname);
   /**
    * Perform a unary operator with the given name
    */
-  Array DoUnaryOperator(const tree &t, UnaryFunc fnc, string fname);
+  Array DoUnaryOperator(Tree *t, UnaryFunc fnc, string fname);
   /**
    * Handle the construction of a function pointer
    */
-  Array FunctionPointer(const tree &args);
+  Array FunctionPointer(Tree *args);
   /**
    * Dispatch a function pointer
    */
-  ArrayVector FunctionPointerDispatch(Array r, const tree &args, int narg_out);
+  ArrayVector FunctionPointerDispatch(Array r, Tree *args, int narg_out);
   /**
    * Set the context of the interpreter.  This is an integer that indicates
    * where in the source file we are.
@@ -664,7 +698,7 @@ private:
    *   |   rowDef
    *   rowDef
    */
-  Array matrixDefinition(const tree &t);
+  Array matrixDefinition(Tree *t);
   /**
    * Convert a cell defintion of the form: {expr1,expr2;expr3;expr4} into
    * a vector of row definitions.  The first row is the vector {expr1,expr2}, and
@@ -676,18 +710,18 @@ private:
    *   |   rowDef
    *   rowDef
    */
-  Array cellDefinition(const tree &t);
+  Array cellDefinition(Tree *t);
   /**
    * Evaluate the expression pointed to by the AST t into a variable.
    */
-  Array expression(const tree &t);
+  Array expression(Tree *t);
 
-  ArrayVector handleReindexing(const tree &t, const ArrayVector &p);
+  ArrayVector handleReindexing(Tree *t, const ArrayVector &p);
   
   /**
    * Evaluate the expression into a variable-array
    */
-  void multiexpr(const tree &t, ArrayVector& m, int lhsCount = 1);
+  void multiexpr(Tree *t, ArrayVector& m, int lhsCount = 1);
 
   /**
    * Evaluate a unit colon expression.  The AST input should look like:
@@ -699,7 +733,7 @@ private:
    * [expr1,expr1+1,expr1+2,...,expr1+n], where n is the largest 
    * integer such that expr1+n <= expr2.
    */
-  Array unitColon(const tree &t);
+  Array unitColon(Tree *t);
   /**
    * Evaluate a double colon expression.  The AST input should look like:
    *   :
@@ -711,7 +745,7 @@ private:
    * vector [expr1,expr1+expr2,expr1+2*expr2,...,expr1+n*expr2], where
    * n is the largest integer such that expr1+n*expr2 <= expr3.
    */
-  Array doubleColon(const tree &t);
+  Array doubleColon(Tree *t);
   /**
    * Decode references to ":" inside variable dereferences.
    */
@@ -719,7 +753,7 @@ private:
   /**
    * Handle statements that are simply expressions
    */
-  void expressionStatement(const tree &t, bool printIt);
+  void expressionStatement(Tree *t, bool printIt);
   /**
    * The RHS expression is used to represent an rvalue in an
    * assignment statement (or an implicit assignment such as 
@@ -747,15 +781,15 @@ private:
    *      either a variable or function.  
    *    - 
    */
-  ArrayVector rhsExpression(const tree &t, int lhsCount = 1);
+  ArrayVector rhsExpression(Tree *t, int lhsCount = 1);
 
-  void assign(ArrayReference r, const tree &s, Array &data);
+  void assign(ArrayReference r, Tree *s, Array &data);
 
-  void multiassign(ArrayReference r, const tree &s, ArrayVector& m);
+  void multiassign(ArrayReference r, Tree *s, ArrayVector& m);
 
-  void deref(Array &r, const tree &s);
+  void deref(Array &r, Tree *s);
 
-  Array rhs(const tree &t);
+  Array rhs(Tree *t);
   /**
    * Look up an identifier as a potential function name, using a
    * rescan if the identifier is not found on the first pass.
@@ -765,13 +799,13 @@ private:
   /**
    * Special case the single assignment statement 'A = B' for speed.
    */
-  void assignment(const tree &var, bool printIt, Array &b);
+  void assignment(Tree *var, bool printIt, Array &b);
   /**
    * Try to figure out how many outputs there should be to a multifunction
    * call.  In particular, logic is used to figure out what to do about
    * undefined variables.
    */
-  int countLeftHandSides(const tree &t);
+  int countLeftHandSides(Tree *t);
   /**
    * Evaluate a function and return the results of the function as
    * an ArrayVector.  For scripts, the body of the function is
@@ -791,7 +825,7 @@ private:
    *    - if too many arguments are passed to the function.
    *    - too many outputs are requested from the function.
    */
-  void functionExpression(const tree &t, int narg_out, bool outputOptional, ArrayVector &output);
+  void functionExpression(Tree *t, int narg_out, bool outputOptional, ArrayVector &output);
   /**
    * A multifunction call is an expression of the sort
    * [expr1,expr2,...,exprn] = func(args).  The AST is
@@ -812,7 +846,7 @@ private:
    * Throws an exception if the AST is malformed (i.e., the '[]' is
    * missing, or there are multiple rows in the left hand side.).
    */
-  void multiFunctionCall(const tree &t, bool printIt);
+  void multiFunctionCall(Tree *t, bool printIt);
   /**
    * A special function call is an expression of the form
    * >> func arg1 arg2 arg3
@@ -821,7 +855,7 @@ private:
    *       |
    *       fname->arg
    */
-  void specialFunctionCall(const tree &t, bool printIt);
+  void specialFunctionCall(Tree *t, bool printIt);
   /**
    * Handles an if statement, corresponding to an if, a number
    * of elseif blocks and an optional else statement.  The AST looks
@@ -833,7 +867,7 @@ private:
    * where each of the elseIf blocks are tested sequentially until
    * one of them succeeds.
    */
-  void ifStatement(const tree &t);
+  void ifStatement(Tree *t);
   /**
    * Handle a switch statement.  The switch statement tests
    * an expression against a number of case blocks.  If a 
@@ -853,7 +887,7 @@ private:
    * Throws an Exception if the switch expression is not
    * either a scalar or a string.
    */
-  void switchStatement(const tree &t);
+  void switchStatement(Tree *t);
   /**
    * Implements the for control statement.  The AST looks like
    *     ident->codeBlock
@@ -864,21 +898,21 @@ private:
    * on each of the values in the expression.  For each such
    * assignment, the code in the codeBlock is executed.
    */
-  void forStatement(const tree &t);
+  void forStatement(Tree *t);
   /**
    * Implements the while control statement.  The AST looks like
    *     expr->codeBlock
    * The test expression is evaluated until it fails, and for each
    * successful expression, the codeBlock is executed.
    */
-  void whileStatement(const tree &t);
+  void whileStatement(Tree *t);
   /**
    * Implements the try statement.  The AST looks like
    *     block->catchBlock
    * The code in block is executed.  If an exception occurs, then
    * the code in catchBlock is executed.
    */
-  void tryStatement(const tree &t);
+  void tryStatement(Tree *t);
   /**
    * Implements the global statement (really a global declaration).
    * The AST looks like:
@@ -890,7 +924,7 @@ private:
    * Each identifier is added to the global variable list of
    * the current context.
    */
-  void globalStatement(const tree &t);
+  void globalStatement(Tree *t);
   /**
    * Implements the persistent statement (really a persistent declaration).
    * The AST looks like:
@@ -902,7 +936,7 @@ private:
    * Each identifier is added to the persistent variable list of
    * the current context.
    */
-  void persistentStatement(const tree &t);
+  void persistentStatement(Tree *t);
   /**
    * This somewhat strange test is used by the switch statement.
    * If x is a scalar, and we are a scalar, this is an equality
@@ -920,7 +954,7 @@ private:
    * the test is returned.  Throws an exception if the AST is
    * malformed.
    */
-  bool testCaseStatement(const tree &t, Array x);
+  bool testCaseStatement(Tree *t, Array x);
   /**
    * Execute the statement described by the AST - the printIt flag
    * determines if the result of the statement should be printed to
@@ -983,8 +1017,8 @@ private:
    * the special variable "ans".
    * Throws an Exception if the statement type is not recognized.
    */
-  void processBreakpoints(const tree &t);
-  void statementType(const tree &t, bool printIt);
+  void processBreakpoints(Tree *t);
+  void statementType(Tree *t, bool printIt);
   /**
    * The statement method simply screens out the need for the
    * printIt flag.  It also retrieves the statement context
@@ -1003,12 +1037,12 @@ private:
    * The context data is supplied by the parse (indicates the
    * line number and filename if necessary).
    */
-  void statement(const tree &t);
+  void statement(Tree *t);
   /**
    * Handles the logistics of shortcut evaluation
    */
-  Array ShortCutOr(const tree &t);
-  Array ShortCutAnd(const tree &t);
+  Array ShortCutOr(Tree *t);
+  Array ShortCutAnd(Tree *t);
   /**
    * Display an array - added so user classes divert to "display" function
    */
@@ -1050,8 +1084,8 @@ private:
    */
   void procFileMex(string fname, string fullname, bool tempfunc);
 
-  friend Array IndexExpressionToStruct(Interpreter*, const tree&, Array);
-  friend ArrayVector ClassRHSExpression(Array, const tree&, Interpreter*);
+  friend Array IndexExpressionToStruct(Interpreter*, Tree*, Array);
+  friend ArrayVector ClassRHSExpression(Array, Tree*, Interpreter*);
   friend ArrayVector PCodeFunction(int, const ArrayVector&, Interpreter*);
   friend class MFunctionDef;
   friend class ImportedFunctionDef;
