@@ -21,19 +21,17 @@
 
 #include "HandleObject.hpp"
 
-namespace FreeMat {
-  class HandleText : public HandleObject {
-    QFont fnt;
-    std::string text;
-  public:
-    HandleText();
-    virtual ~HandleText();
-    virtual void ConstructProperties();
-    virtual void SetupDefaults();
-    virtual void UpdateState();
-    virtual void PaintMe(RenderEngine& gc);
-    int GetTextHeightInPixels();
-  };
-}
+class HandleText : public HandleObject {
+  QFont fnt;
+  std::string text;
+public:
+  HandleText();
+  virtual ~HandleText();
+  virtual void ConstructProperties();
+  virtual void SetupDefaults();
+  virtual void UpdateState();
+  virtual void PaintMe(RenderEngine& gc);
+  int GetTextHeightInPixels();
+};
 
 #endif
